# touchbit.py
# Version 1.0 - May 7, 2019

from microbit import *

a = 0x2c
r_cal = 0x26
r_led = 0x72
r_ctl = 0x00
r_status = 0x03

def readByte(reg):
    i2c.write(a, bytes([reg]))
    return i2c.read(a, 1)[0]

def writeByte(reg, val):
    val = [val]
    val.insert(0, reg)
    i2c.write(a, bytes(val))

btn_states = [False] * 6
down_states = [False] * 6

def pollButtons():
    if readByte(r_ctl) & 1:  
        writeByte(r_ctl, 0x00) 
        state = readByte(r_status)
        mask = 1
        for i in range(6):
            if state & mask != 0:
                onButtonEvent(i, True)
                btn_states[i] = True
            else:
                if btn_states[i]:
                    onButtonEvent(i, False)
                    btn_states[i] = False    
            mask = mask << 1

def setup():
    writeByte(r_cal, 0xff) # recalibration
    writeByte(r_led, 0x3f) # default LED linking
    
def onButtonEvent(btn, down):
    if down:
        if not down_states[btn]:
            if callbacks[0] != None:
                callbacks[0](btn)
            down_states[btn] = True
        else:
            if callbacks[2] != None:
                callbacks[2](btn)
    else:
        if down_states[btn]:
            if callbacks[1] != None:
                callbacks[1](btn)
            down_states[btn] = False    

def registerCallbacks(buttonPress = None, buttonRelease = None, buttonRepeat = None):
    global callbacks
    callbacks = [buttonPress, buttonRelease, buttonRepeat]
    
setup()
callbacks = [None, None, None]    